local json = require("json")
local const = require("const")
local utils = require("utils3")

utils.check_request_method("GET")
utils.check_auth()
utils.check_permission("SceneManage")

local function list_scenes()
    local ret, err, cause = utils.dbus_call_edge(
            const.scene.wkn, const.scene.obj, const.scene.inf,
            const.scene.method.list_scene_stats)
    if not ret then
        return false, err, "failed to list scenes: " .. cause
    end

    local ok, res = pcall(json.decode, ret[1])
    if not ok or type(res) ~= "table" then
        return false, const.MESSAGE_INVALIDREPLY, "not a JSON object"
    end
    if res["code"] ~= 0 then
        local msg = { code = res["code"], message = res["message"] }
        return false, const.MESSAGE_FAILEDREPLY, json.encode(msg)
    end
    if not res["data"] or type(res["data"]) ~= "table" then
        return false, const.MESSAGE_INVALIDREPLY, "no data found or data not a JSON object"
    end

    local scenes = {}
    for _, v in ipairs(res["data"]) do
        local scene = {}
        scene["Id"] = v["id"] or ""
        scene["Name"] = v["name"] or ""
        scene["Running"] = v["running"]
        table.insert(scenes, scene)
    end
    return true, scenes, nil
end

local ok, ret, err = list_scenes()
if not ok then
    return utils.error_exit(
            ngx.HTTP_INTERNAL_SERVER_ERROR,
            ret, err)
end

local resp = {}
resp["Data"] = {}
resp["Data"]["Scenes"] = ret
local str = json.encode(resp)
ngx.header['Content-Type'] = 'application/json; charset=utf-8'
ngx.say(str)