local json = require("json")
local utils = require("utils")
local pl_path = require("pl.path")

utils.check_login()
utils.check_permission("DriverManage")

local request_method = ngx.var.request_method
if request_method ~= "POST" then
    return utils.error_exit(405, "unsupported request method: " .. request_method)
end

local utils_header = require("utils_header")
local params = utils_header.check_public_body_data()
local driver_id = params["DriverId"]
if type(driver_id) ~= "string" or #driver_id == 0 then
    return utils.error_exit(400, "DriverId is not string or is empty")
end

local homepage_root = string.format("%s/drivers/%s/homepage", ngx.var.drivers_prefix, driver_id)
local exist = pl_path.exists(string.format("%s/index.html", homepage_root))
local resp = {
    code = 200,
    message = "success",
    data = {}
}
resp.data["Exist"] = exist
ngx.say(json.encode(resp))