local json = require("json")
local utils = require("utils")

utils.check_login()
utils.check_permission("DriverManage")

local request_method = ngx.var.request_method
if request_method ~= "POST" then
    return utils.error_exit(405, "unsupported request method: " .. request_method)
end

local utils_header = require("utils_header")
local params = utils_header.check_public_body_data()
local driver_id = params["DriverId"]
if type(driver_id) ~= "string" or #driver_id == 0 then
    return utils.error_exit(400, "driver id is not string or is empty")
end

local keys, err = utils.get_driver_keys(driver_id)
if not keys then
    return utils.error_exit(500, err)
end

-- https://yuque.antfin-inc.com/feifei.gff/dazb8y/hnndba
-- values: {"Power":{"value":"on","time":1524448722000}}
local ok, message, values = utils.get_driver_values(driver_id, keys)

if ok == false then
    message = "warning: didn't retrieve all keys from driver."
    for _,v in pairs(keys) do
        if nil == values[v] then
            values[v] = {
                value = ""
            }
        end
    end
    -- 2020-01-14 return keys with default values in return
    -- return utils.error_exit(500, err)
end

local resp = {}
resp["code"] = 200
resp["message"] = message
resp["data"] = { Values = values }
ngx.say(json.encode(resp))