local json = require("json")
local utils = require("utils")
local driver_utils = require("driver_utils")

local request_method = ngx.var.request_method

utils.check_login()
utils.check_permission("DriverManage") 

if ("POST" == request_method) then
    local utils_header = require("utils_header")
    local params = utils_header.check_public_body_data()
    local page_size = tonumber(params["PageSize"])
    local cur_page = tonumber(params["CurrentPage"])
    page_size = utils.check_page_size_allow_zero(page_size)
    utils.check_current_page(cur_page)

    local list = {}
    local driver_list = driver_utils.get_driver_list_detail( )
    if (driver_list and next(driver_list)) then
        -- get all driver name and sort them
        driver_name_list = {}
        for k, v in pairs(driver_list) do
            if v["DriverName"] ~= "gateway_monitor" then
                table.insert(driver_name_list, k)
            end
        end
        table.sort(driver_name_list)
        total_num = #driver_name_list

        local min, max = utils.get_item_index(total_num, page_size, cur_page)
        for n = min, max do 
            item = {}
            item["DriverName"] = driver_list[driver_name_list[n]]["DriverName"]
            --FIXME: get these info from ssc .
            if item["DriverName"] == "opcua" or item["DriverName"] == "Modbus" or item["DriverName"] == "websocket" then
                item["Deletable"] = false
            else
                item["Deletable"] = true
            end
            item["DriverType"] = driver_list[driver_name_list[n]]["DriverType"]
            item["DriverState"] = "working"
            item["DeviceNum"] = driver_list[driver_name_list[n]]["DeviceNum"]
            item["LoadTime"] = driver_list[driver_name_list[n]]["LoadTime"]
            table.insert(list, item)
        end
    else
        total_num = 0
    end

    local res = {}
    res["TotalNum"] = total_num
    res["PageSize"] = page_size
    res["CurrentPage"] = cur_page
    res["List"] = list
    utils.error_exit(200, json.encode(res)) 
end

utils.error_exit(400, "unsupported request method")
------ EOF ------
