local json = require("json")
local utils = require("utils")
local const = require("const")
local request_method = ngx.var.request_method

utils.check_login()
utils.check_permission("DriverManage", "FunctionComputeManage")

if "POST" ~= request_method then
    utils.error_exit(405, "unsupported request method: " .. request_method)
end

local utils_header = require("utils_header")
local params = utils_header.check_public_body_data()
local driver_id = params["DriverId"]
if type(driver_id) ~= "string" or #driver_id == 0 then
    utils.error_exit(400, "driver id is not string or is empty")
end

local function_ids = string.format('{"functions":[{"functionId":"%s"}]}', driver_id)
local ok, msg_raw, err = utils.dbus_call_edge(const.function_compute.wkn,
        const.function_compute.obj,
        const.function_compute.inf,
        const.function_compute.method.restart_functions,
        function_ids)

if not ok or not msg_raw[1] then
    utils.error_exit(500, err)
end

local ok, res = pcall(json.decode, msg_raw[1])
if not ok then
    utils.error_exit(500, "response from upstream service not in JSON")
end

local resp = {}
if res["code"] == 0 then
    resp["code"] = 200
    resp["message"] = "success"
    resp["data"] = res["data"]
else
    resp["code"] = 500
    resp["message"] = res["message"]
    resp["data"] = res["data"]
end
ngx.say(json.encode(resp))