local utils = require("utils")

utils.check_login()
utils.check_permission("DriverManage")

local request_method = ngx.var.request_method
if request_method ~= "POST" then
    return utils.error_exit(405, "unsupported request method: " .. request_method)
end

local utils_header = require("utils_header")
local params = utils_header.check_public_body_data()
local driver_id = params["DriverId"]
local mode = params["Mode"]
if type(driver_id) ~= "string" or #driver_id == 0 then
    return utils.error_exit(400, "driver id is not string or is empty")
end
if type(mode) ~= "string" or #mode == 0 then
    return utils.error_exit(400, "driver mode is not string or is empty")
end

local dm
if mode == "kv" then
    dm = "1"
elseif mode == "tsl" then
    dm = "0"
else
    return utils.error_exit(400, "driver mode should be kv or tsl")
end

local ok, err = utils.set_driver_mode(driver_id, dm)
if not ok then
    return utils.error_exit(500, err)
end
utils.error_exit(200)