local json = require("json")
local utils = require("utils")
local driver_utils = require("driver_utils")
local utils_device = require("utils_device")
local const = require("const")
local pl_utils = require("pl.utils")

local request_method = ngx.var.request_method

utils.check_login()
utils.check_permission("GatewayManage") 

local function get_netcard_state(cardname)
    local cmd = 'ping -c 1 8.8.8.8 -I ' .. cardname
    local ok, retcode, _, _ = utils.call_shell(cmd)
    if (0 == retcode) then
        return true
    end

    return false
end

--ip address show up | egrep "global|link/ether" | awk '{i = 2; for (; i <= NF; i++){ if ((i == 2 && index($(i),".") != 0) || (index($(i), ":") != 0 && index($(i), "ff:ff:ff:ff:ff:ff") == 0) || (i == NF && $(i) != 0)) {printf "%s\n",$(i)}}}'
local function get_netcard_list()
    local cmd_ip_show = "/usr/sbin/ip address show up | "
    local cmd_grep = "egrep \"global|link/ether\" | "
    local cmd_awk_start = "awk '{i = 2; for (; i <= NF; i++){ if (" 
    local cmd_awk_ip = "(i == 2 && index($(i),\".\") != 0) || " 
    local cmd_awk_mac = "(index($(i), \":\") != 0 && index($(i), \"ff:ff:ff:ff:ff:ff\") == 0) || " 
    local cmd_awk_name = "(i == NF && $(i-1) == \"global\")"
    local cmd_awk_end = ") {printf \"%s\",$(i); $(i); count += 1; if (count%3 == 0) printf \";\"; else printf \" \"}}}'" 

    local cmd = cmd_ip_show..cmd_grep..cmd_awk_start..cmd_awk_ip..cmd_awk_mac..cmd_awk_name..cmd_awk_end
    local ret_cmd, actual, stdout, errout = pl_utils.executeex(cmd, false)
    if ret_cmd then
        local res = utils.split_str(stdout, ";")
        local ret = {}
        for k, v in ipairs(res) do
            local res_child =  utils.split_str(v, " ")
            if res_child[3] ~= nil and res_child[4] == nil then 
                    local item = {}
                    item["mac"] = res_child[1]
                    item["ip"] = res_child[2]
                    item["name"] = res_child[3]
                    item["internet"] = get_netcard_state(res_child[3])
                    table.insert(ret, item)
            end
        end
        return ret
    end

    return {}
end

if ("POST" == request_method) then 
    local utils_header = require("utils_header")
    local params = utils_header.check_public_body_data()
    local ok1, msg_pk = utils.get_data(const.data_key.gwconfig.productkey)
    local ok2, msg_dn = utils.get_data(const.data_key.gwconfig.devicename)
    local ok3, msg_ds = utils.get_data(const.data_key.gwconfig.devicesecret)
    if (not (ok1 and ok2 and ok3)) then
        utils.log_error("get gateway config failed" .. msg_pk .. msg_dn .. msg_ds)
        utils.error_exit(500, "get data failed")
    end

    local data = {}
    local msg_ret = {} 
    data["productKey"] = msg_pk
    data["deviceName"] = msg_dn
    data["deviceSecret"] = msg_ds

    local ok, msg = utils_device.get_3tuple()
    if ok and msg ~= nil and #msg > 1 then
        local device_3tuple = json.decode(msg)
        local subDevice = {}
        for k, v in pairs(device_3tuple) do
            local tmp = {}
            local pk = v[1]
            local dn = v[2]
            local ds = v[3]

            tmp["productKey"] = pk
            tmp["deviceName"] = dn
            tmp["deviceSecret"] = ds

            table.insert(subDevice, tmp)
        end
        data["subDevice"] = subDevice
    end
    data["network"] = get_netcard_list()
    msg_ret["code"] = 200
    msg_ret["message"] = "success"
    msg_ret["data"] = data 
    ngx.say(json.encode(msg_ret)) 
    ngx.exit(ngx.HTTP_OK)
end

utils.error_exit(400, "unsupported request method")
------ EOF ------
