--- Upload a OTA firmware.
-- Based on source: https://github.com/openresty/lua-resty-upload.
local json = require("json")
local utils = require("utils")
local resty_md5 = require("resty.md5")
local resty_random = require("resty.random")
local resty_string = require("resty.string")
local upload = require("resty.upload")

utils.check_login()
utils.check_permission("OTAManage")

local request_method = ngx.var.request_method
if request_method ~= "POST" then
    return utils.error_exit(405, "unsupported request method: " .. request_method)
end

local function get_form_data_name(header)
    return string.match(header, '^form%-data; name="(.-)".*')
end

local firmware_id = resty_string.to_hex(resty_random.bytes(16))
local chunk_size = 4096
local form = upload:new(chunk_size)
local md5 = resty_md5:new()
local file
local digest
local md5ing = false
local md5sum = ""
while true do
    local typ, res, err = form:read()
    if not typ then
        return utils.error_exit(400, "failed to read: " .. err)
    end
    if typ == "header" then
        if res[1] == "Content-Disposition" then
            local name = get_form_data_name(res[2])
            if name == "firmware" then
                local file_name = ngx.var.firmware_root .. "/" .. firmware_id
                file = io.open(file_name, "w+")
                if not file then
                    return utils.error_exit(500, "failed to create file")
                end
            elseif name == "md5sum" then
                md5ing = true
            end
        end
    elseif typ == "body" then
        if file then
            file:write(res)
            md5:update(res)
        elseif md5ing then
            md5sum = md5sum .. res
        end
    elseif typ == "part_end" then
        if file then
            file:flush()
            file:close()
            file = nil
            digest = resty_string.to_hex(md5:final())
            md5:reset()
        elseif md5ing then
            md5ing = false
        end
    elseif typ == "eof" then
        break
    else
        -- do nothing
    end
end

if digest ~= md5sum then
    local err = string.format("mismatch md5sum: md5sum=%s, digest=%s", md5sum, digest)
    return utils.error_exit(400, err)
end

local resp = {
    code = 200,
    message = "success",
    data = {}
}
resp.data["FirmwareId"] = firmware_id
ngx.say(json.encode(resp))