local json = require("json")
local utils = require("utils")

local utils_header = {}

function utils_header.check_public_body_data()
    ngx.req.read_body()
    local args_json = ngx.req.get_body_data()
    if not args_json then
        local file_name = ngx.req.get_body_file()
        if file_name then
            local f = io.open(file_name, "r")
            if not f then
                utils.error_exit(503, "failed to read body")
            end
            args_json = f:read("*all")
            f:close()
        end
    end
    if (nil == args_json) then
        utils.error_exit(400, "request is empty")
    end

    local ok, args = pcall(json.decode, args_json)
    if not ok then
        utils.error_exit(400, "request is not in JSON")
    end

    local request = args["request"]
    if (request == nil) then
        utils.error_exit(400, "'request' is empty")
    end

    local apiVer = request["apiVer"]
    if (apiVer ~= "0.6") then
        utils.error_exit(400, "'apiVer' must be 0.6")
    end

    local params = args["params"]
    if type(params) ~= "table" then
        utils.error_exit(400, "'params' is empty or not in JSON")
    end

    return params
end

return utils_header
