#!/usr/bin/env python3
# -*- coding: utf-8 -*-


# /*返回状态*/

LEDA_SUCCESS                    = 0       # 执行成功
LEDA_ERROR_UNKNOWN              = 100000  # 不能被识别的错误，用户不应该看到的错误
LEDA_ERROR_INVAILD_PARAM        = 100001  # 传入参数为NULL或无效
LEDA_ERROR_NO_MEM               = 100002  # 指定的内存分配失败
LEDA_ERROR_TIMEOUT              = 100006  # 超时
LEDA_ERROR_NOT_SUPPORT          = 100008  # 服务不可达

LEDA_ERROR_DEVICE_UNREGISTER    = 109000  # 设备未注册
LEDA_ERROR_DEVICE_OFFLINE       = 109001  # 设备已下线
LEDA_ERROR_PROPERTY_NOT_EXIST   = 109002  # 属性不存在
LEDA_ERROR_PROPERTY_READ_ONLY   = 109003  # 属性不允许写
LEDA_ERROR_PROPERTY_WRITE_ONLY  = 109004  # 属性不允许读
LEDA_ERROR_SERVICE_NOT_EXIST    = 109005  # 服务不存在
LEDA_ERROR_SERVICE_INPUT_PARAM  = 109006  # 服务参数未验证
LEDA_ERROR_INVALID_JSON         = 109007  # JSON格式错误
LEDA_ERROR_INVALID_TYPE         = 109008  # 参数类型错误

# 用户自定义错误码范围
LEDA_ERROR_USER_MIN             = 109200
LEDA_ERROR_USER_MAX             = 109899
# 109899 ~ 109200          /* 设备厂商（预留）自定义错误码区间范围 */
# 对于返回错误码在标准错误码区间和自定义范围内，接入SDK会透传到云端，不在该区间内错误码会统一转换为100000错误码


class LedaException(Exception):
    '''
		base leda exception
	'''

    def __init__(self, msg="", value=LEDA_ERROR_UNKNOWN):
        '''
		Initialize the exception
		:param value: the err code
		:param msg: the err msg
		'''
        self.value = value
        self.msg = msg

    def __str__(self):
        '''
		return the exception message
		:return str:
		'''

        return "Err: %s ErrCode: %s" % (str(self.msg), self.value)

    __repr__ = __str__


class LedaParamsException(LedaException):
    ''' leda params error'''

    def __init__(self, msg="", value=LEDA_ERROR_UNKNOWN):
        '''Initialize the exception
		:param value: the err code
		:param msg: the err msg
		'''

        message = "[LedaParams] %s" % (str(msg))
        LedaException.__init__(self, message, value)


class LedaRPCMethodException(LedaException):
    ''' leda rpc method error'''

    def __init__(self, msg="", value=LEDA_ERROR_UNKNOWN):
        '''Initialize the exception
		:param value: the err code
		:param msg: the err msg
		'''

        message = "[LedaRPCMethod] %s" % (str(msg))
        LedaException.__init__(self, message, value)


class LedaBusHandleException(LedaException):
    ''' leda busHandle error'''

    def __init__(self, msg="", value=LEDA_ERROR_UNKNOWN):
        '''Initialize the exception
		:param value: the err code
		:param msg: the err msg
		'''

        message = "[LedaBusHandle] %s" % (str(msg))
        LedaException.__init__(self, message, value)


class LedaFeedDogException(LedaException):
    ''' leda feed dog error'''

    def __init__(self, msg="", value=LEDA_ERROR_UNKNOWN):
        '''Initialize the exception
		:param value: the err code
		:param msg: the err msg
		'''

        message = "[LedaFeedDog] %s" % (str(msg))
        LedaException.__init__(self, message, value)


class LedaCallBackException(LedaException):
    ''' leda call back error'''

    def __init__(self, msg="", value=LEDA_ERROR_UNKNOWN):
        '''Initialize the exception
		:param value: the err code
		:param msg: the err msg
		'''

        message = "[LedaCallBack] %s" % (str(msg))
        LedaException.__init__(self, message, value)


class LedaReportPropertyException(LedaException):
    ''' leda report property error'''

    def __init__(self, msg="", value=LEDA_ERROR_UNKNOWN):
        '''Initialize the exception
		:param value: the err code
		:param msg: the err msg
		'''

        message = "[LedaReportProperty] %s" % (str(msg))
        LedaException.__init__(self, message, value)


class LedaReportEventException(LedaException):
    ''' leda report event error'''

    def __init__(self, msg="", value=LEDA_ERROR_UNKNOWN):
        '''Initialize the exception
		:param value: the err code
		:param msg: the err msg
		'''

        message = "[LedaReportEvent] %s" % (str(msg))
        LedaException.__init__(self, message, value)
